@@ -21,5 +21,10 @@ class MFALoginView(LoginView):
 
     def get_response(self):
         if self.user.mfa:
-            return Response({"requires_mfa": True})
+            user_key_types = (
+                self.user.userkey_set.all()
+                .values_list("key_type", flat=True)
+                .distinct()
+            )
+            return Response({"requires_mfa": True, "valid_auth": user_key_types})
         return super().get_response()
